{============================================================}
{                   Oracle Reports 2.5                       }
{ TOraRep component incapsulated the Reports OCI library     }
{                 Sergey Perevoznik, 1998                    }
{     R25OCI32.DLL must be present in SYSTEM directory       }
{============================================================}

unit OraRep;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Dsgnintf;

type
  TOraRep = class(TComponent)
  private
    { Private declarations }
    FReportName : string;
    FUserName   : string;
    FPassword   : string;
    FConnectString : PChar;
    FCmdLine    : string;
  protected
    { Protected declarations }
    Procedure GenerateCmdLine;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    Procedure Run;
    Procedure Edit;
    Procedure Convert;
    procedure SetVariable(const Name, Value: string);
  published
    { Published declarations }
    property ReportName : string read FReportName Write FReportName;
    property Username : string read FUserName Write FUserName;
    property Password : string read FPassword Write FPassword;
  end;

  TOraRepNameProperty = class(TStringProperty)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
  end;

  TOraRepEditor = class(TComponentEditor)
    function  GetVerbCount : integer ; override;
    function  GetVerb(Index:integer) : string; override;
    procedure ExecuteVerb(Index:integer); override;
  end;

procedure Register;

implementation

uses rwoci;

constructor TOraRep.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FCmdLine := '';
end;

procedure TOraRep.SetVariable(const Name, Value: string);
begin
  FCmdLine := FCmdLine + Name +'='+Value+' ';
end;

Procedure TOraRep.GenerateCmdLine;
begin
 FConnectString := Pchar(FReportName+ ' userid='+FUserName+'/'+FPassword + ' '+
 FCmdLine + #0);
end;

Procedure TOraRep.Run;
begin
  GenerateCmdLine;
  rwcrrb(FConnectString);
end;

Procedure TOraRep.Edit;
begin
  FConnectString := Pchar(FReportName+ ' userid='+FUserName+'/'+FPassword + #0);
  rwcsrb(FConnectString);
end;

Procedure TOraRep.Convert;
begin
 GenerateCmdLine;
 rwccon(FConnectString);
end;

procedure TOraRepNameProperty.Edit;
var
  RepFileOpen: TOpenDialog;
begin
  RepFileOpen := TOpenDialog.Create(Application);
  RepFileOpen.Filename := GetValue;
  RepFileOpen.Filter := 'Report Definition (*.rdf)|*.rdf|Report Runtime (*.rep)|*.rep';
  RepFileOpen.Options := RepFileOpen.Options + [ofPathMustExist,
    ofFileMustExist];
  try
    if RepFileOpen.Execute then SetValue(RepFileOpen.Filename);
  finally
    RepFileOpen.Free;
  end;
end;

function TOraRepNameProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;


function TOraRepEditor.GetVerbCount : integer ;
begin
  Result := 2;
end;

function TOraRepEditor.GetVerb(Index:integer) : string;
begin
  Case Index of
  0: Result := 'Edit report';
  1: Result := 'Run report';
 end;
end;

procedure TOraRepEditor.ExecuteVerb(Index:integer);
begin
  case index of
   0:begin
      if TOraRep(Component).FUserName = '' then
        begin
          ShowMessage('User name must be set');
          Exit;
        end;
      if TOraRep(Component).FPassword = '' then
        begin
          ShowMessage('Password must be set');
          Exit;
        end;
      TOraRep(Component).Edit;
     end;
   1:begin
      if TOraRep(Component).FUserName = '' then
        begin
          ShowMessage('User name must be set');
          Exit;
        end;
      if TOraRep(Component).FPassword = '' then
        begin
          ShowMessage('Password must be set');
          Exit;
        end;
     TOraRep(Component).Run;
    end;
 end;
end;

procedure Register;
begin
  RegisterComponents('Data Access', [TOraRep]);
  RegisterPropertyEditor(TypeInfo(String), TOraRep, 'ReportName', TOraRepNameProperty);
  RegisterComponentEditor(ToraRep,TOraRepEditor);
end;

end.
